@@ -4,8 +4,8 @@ import argparse
 import sys
 
 from datalake_scripts.common.base_script import BaseScripts
-from datalake_scripts.scripts import add_new_threats, get_threats_by_hashkey, edit_score, get_threats_from_query_hash, \
-    add_new_comment_or_tags
+from datalake_scripts.scripts import add_threats, get_threats_by_hashkey, edit_score, get_threats_from_query_hash, \
+    add_new_comment_or_tags, lookup_threats
 
 
 class Cli:
@@ -38,7 +38,7 @@ The most commonly used {self.CLI_NAME} commands are:
 
     def add_threats(self):
         args = sys.argv[2:]
-        add_new_threats.main(args)
+        add_threats.main(args)
 
     def get_threats(self):
         args = sys.argv[2:]
@@ -56,6 +56,10 @@ The most commonly used {self.CLI_NAME} commands are:
         args = sys.argv[2:]
         add_new_comment_or_tags.main(args)
 
+    def lookup_threat(self):
+        args = sys.argv[2:]
+        lookup_threats.main(args)
+
     def _list_commands_available(self):
         method_list = []
         for method_name in dir(self):
