@@ -14,13 +14,17 @@ class PostEngine(BaseEngine):
         'as',
         'cc',
         'crypto',
+        'cve',
         'domain',
         'email',
         'file',
         'fqdn',
+        'iban',
         'ip',
         'ip_range',
         'paste',
+        'phone_number',
+        'regkey',
         'ssl',
         'url',
     ]
@@ -122,7 +126,7 @@ class AddThreatsPost(PostEngine):
         return payload
 
     def add_threats(self, atom_list: list, atom_type: str, white: bool, threats_score: Dict[str, int], is_public: bool,
-                    tags: list, links: list) -> dict:
+                    tags: list, links: list, override_type: str) -> dict:
         """
         Use it to add a list of threats to the API.
 
@@ -133,8 +137,10 @@ class AddThreatsPost(PostEngine):
         :param is_public: if true the added threat will be public else will be reserved to organization
         :param tags: a list of tags to add
         :param links: external_analysis_link to include with each atoms
+        :param override_type: either 'permanent' or 'temporary'. Permanent don't allow future automatic score change
         """
         payload = {
+            'override_type': override_type,
             'public': is_public,
             'threat_data': {
                 'content': {},
@@ -230,7 +236,7 @@ class ThreatsScoringPost(PostEngine):
         logger.debug('url : ' + repr(self.url))
         return self.datalake_requests(f'{self.url}{hashkey}/scoring-edits/', 'post', self._post_headers(), payload)
 
-    def post_new_score_from_list(self, hashkeys: set, scores: Dict[str, int], override_type: str = 'temporary') -> list:
+    def post_new_score_from_list(self, hashkeys: list, scores: Dict[str, int], override_type: str = 'temporary') -> list:
         """
         Post new score to the API from a list of hashkeys
         """
